@@ -6,9 +6,9 @@ The goal of Xplique is to provide a simple interface to the latest explanation
 techniques
 """
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 
 from . import attributions
 from . import concepts
 from . import features_visualizations
-from . import utils
+from . import commons
